@@ -8,7 +8,7 @@ from numpy.typing import ArrayLike
 
 hookimpl = HookimplMarker("ffmpegio")
 
-__version__ = "0.6.0.post"
+__version__ = "0.7.0"
 # When updating version, make sure to update setup.cfg install_requires 
 # ffmpegio-core version to match current ffmpeg-core version
 
@@ -56,7 +56,7 @@ def video_bytes(obj: ArrayLike) -> memoryview:
     :rtype: memoryview
     """
 
-    return memoryview(obj)
+    return memoryview(np.ascontiguousarray(obj))
 
 
 @hookimpl
@@ -69,7 +69,7 @@ def audio_bytes(obj: ArrayLike) -> memoryview:
     :rtype: memoryview
     """
 
-    return memoryview(obj)
+    return memoryview(np.ascontiguousarray(obj))
 
 
 @hookimpl
